<a id="mypy-boto3-honeycode"></a>

# mypy-boto3-honeycode

[![PyPI - mypy-boto3-honeycode](https://img.shields.io/pypi/v/mypy-boto3-honeycode.svg?color=blue)](https://pypi.org/project/mypy-boto3-honeycode)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-honeycode.svg?color=blue)](https://pypi.org/project/mypy-boto3-honeycode)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-honeycode?color=blue)](https://pypistats.org/packages/mypy-boto3-honeycode)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Honeycode 1.18.60](https://boto3.amazonaws.com/v1/documentation/api/1.18.60/reference/services/honeycode.html#Honeycode)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-honeycode docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-honeycode](#mypy-boto3-honeycode)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Honeycode` service.

```bash
python -m pip install boto3-stubs[honeycode]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[honeycode]` in your environment:
  `python -m pip install 'boto3-stubs[honeycode]'`

Both type checking and auto-complete should work for `Honeycode` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[honeycode]` in your environment:
  `python -m pip install 'boto3-stubs[honeycode]'`

Both type checking and auto-complete should work for `Honeycode` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[honeycode]` in your environment:
  `python -m pip install 'boto3-stubs[honeycode]'`
- Run `mypy` as usual

Type checking should work for `Honeycode` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[honeycode]` in your environment:
  `python -m pip install 'boto3-stubs[honeycode]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Honeycode` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`HoneycodeClient` provides annotations for `boto3.client("honeycode")`.

```python
import boto3

from mypy_boto3_honeycode import HoneycodeClient

client: HoneycodeClient = boto3.client("honeycode")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: HoneycodeClient = session.client("honeycode")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_honeycode.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_honeycode import HoneycodeClient
from mypy_boto3_honeycode.paginator import (
    ListTableColumnsPaginator,
    ListTableRowsPaginator,
    ListTablesPaginator,
    QueryTableRowsPaginator,
)

client: HoneycodeClient = boto3.client("honeycode")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_table_columns_paginator: ListTableColumnsPaginator = client.get_paginator("list_table_columns")
list_table_rows_paginator: ListTableRowsPaginator = client.get_paginator("list_table_rows")
list_tables_paginator: ListTablesPaginator = client.get_paginator("list_tables")
query_table_rows_paginator: QueryTableRowsPaginator = client.get_paginator("query_table_rows")
```

<a id="literals"></a>

### Literals

`mypy_boto3_honeycode.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_honeycode.literals import (
    FormatType,
    ImportDataCharacterEncodingType,
    ImportSourceDataFormatType,
    ListTableColumnsPaginatorName,
    ListTableRowsPaginatorName,
    ListTablesPaginatorName,
    QueryTableRowsPaginatorName,
    TableDataImportJobStatusType,
    UpsertActionType,
    ServiceName,
    PaginatorName,
)

def check_value(value: FormatType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_honeycode.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_honeycode.type_defs import (
    BatchCreateTableRowsRequestRequestTypeDef,
    BatchCreateTableRowsResultTypeDef,
    BatchDeleteTableRowsRequestRequestTypeDef,
    BatchDeleteTableRowsResultTypeDef,
    BatchUpdateTableRowsRequestRequestTypeDef,
    BatchUpdateTableRowsResultTypeDef,
    BatchUpsertTableRowsRequestRequestTypeDef,
    BatchUpsertTableRowsResultTypeDef,
    CellInputTypeDef,
    CellTypeDef,
    ColumnMetadataTypeDef,
    CreateRowDataTypeDef,
    DataItemTypeDef,
    DelimitedTextImportOptionsTypeDef,
    DescribeTableDataImportJobRequestRequestTypeDef,
    DescribeTableDataImportJobResultTypeDef,
    DestinationOptionsTypeDef,
    FailedBatchItemTypeDef,
    FilterTypeDef,
    GetScreenDataRequestRequestTypeDef,
    GetScreenDataResultTypeDef,
    ImportDataSourceConfigTypeDef,
    ImportDataSourceTypeDef,
    ImportJobSubmitterTypeDef,
    ImportOptionsTypeDef,
    InvokeScreenAutomationRequestRequestTypeDef,
    InvokeScreenAutomationResultTypeDef,
    ListTableColumnsRequestRequestTypeDef,
    ListTableColumnsResultTypeDef,
    ListTableRowsRequestRequestTypeDef,
    ListTableRowsResultTypeDef,
    ListTablesRequestRequestTypeDef,
    ListTablesResultTypeDef,
    PaginatorConfigTypeDef,
    QueryTableRowsRequestRequestTypeDef,
    QueryTableRowsResultTypeDef,
    ResponseMetadataTypeDef,
    ResultRowTypeDef,
    ResultSetTypeDef,
    SourceDataColumnPropertiesTypeDef,
    StartTableDataImportJobRequestRequestTypeDef,
    StartTableDataImportJobResultTypeDef,
    TableColumnTypeDef,
    TableDataImportJobMetadataTypeDef,
    TableRowTypeDef,
    TableTypeDef,
    UpdateRowDataTypeDef,
    UpsertRowDataTypeDef,
    UpsertRowsResultTypeDef,
    VariableValueTypeDef,
)

def get_structure() -> BatchCreateTableRowsRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-honeycode` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-honeycode docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
